@@ -29,15 +29,13 @@ class AndroidTV(BaseTV):
         The port for the ADB server
     state_detection_rules : dict, None
         A dictionary of rules for determining the state (see :class:`~androidtv.basetv.BaseTV`)
-    auth_timeout_s : float
-        Authentication timeout (in seconds)
 
     """
 
     DEVICE_CLASS = 'androidtv'
 
-    def __init__(self, host, port=5555, adbkey='', adb_server_ip='', adb_server_port=5037, state_detection_rules=None, auth_timeout_s=constants.DEFAULT_AUTH_TIMEOUT_S):
-        BaseTV.__init__(self, host, port, adbkey, adb_server_ip, adb_server_port, state_detection_rules, auth_timeout_s)
+    def __init__(self, host, port=5555, adbkey='', adb_server_ip='', adb_server_port=5037, state_detection_rules=None):
+        BaseTV.__init__(self, host, port, adbkey, adb_server_ip, adb_server_port, state_detection_rules)
 
     # ======================================================================= #
     #                                                                         #
@@ -50,7 +48,7 @@ class AndroidTV(BaseTV):
         Parameters
         ----------
         get_running_apps : bool
-            Whether or not to get the :attr:`~androidtv.basetv.BaseTV.running_apps` property
+            Whether or not to get the :meth:`~androidtv.androidtv.AndroidTV.running_apps` property
 
         Returns
         -------
@@ -84,7 +82,7 @@ class AndroidTV(BaseTV):
 
         # Check if screen saver is on
         elif not awake:
-            state = constants.STATE_IDLE
+            state = constants.STATE_STANDBY
 
         else:
             # Get the running apps
@@ -98,7 +96,7 @@ class AndroidTV(BaseTV):
 
             # ATV Launcher
             if current_app in [constants.APP_ATV_LAUNCHER, None]:
-                state = constants.STATE_STANDBY
+                state = constants.STATE_IDLE
 
             # BELL Fibe
             elif current_app == constants.APP_BELL_FIBE:
@@ -111,7 +109,7 @@ class AndroidTV(BaseTV):
                 elif media_session_state == 3:
                     state = constants.STATE_PLAYING
                 else:
-                    state = constants.STATE_STANDBY
+                    state = constants.STATE_IDLE
 
             # Plex
             elif current_app == constants.APP_PLEX:
@@ -121,7 +119,7 @@ class AndroidTV(BaseTV):
                     else:
                         state = constants.STATE_PLAYING
                 else:
-                    state = constants.STATE_STANDBY
+                    state = constants.STATE_IDLE
 
             # TVheadend
             elif current_app == constants.APP_TVHEADEND:
@@ -130,7 +128,7 @@ class AndroidTV(BaseTV):
                 elif wake_lock_size == 6:
                     state = constants.STATE_PLAYING
                 else:
-                    state = constants.STATE_STANDBY
+                    state = constants.STATE_IDLE
 
             # VLC
             elif current_app == constants.APP_VLC:
@@ -139,7 +137,7 @@ class AndroidTV(BaseTV):
                 elif media_session_state == 3:
                     state = constants.STATE_PLAYING
                 else:
-                    state = constants.STATE_STANDBY
+                    state = constants.STATE_IDLE
 
             # VRV
             elif current_app == constants.APP_VRV:
@@ -152,7 +150,7 @@ class AndroidTV(BaseTV):
                 elif media_session_state == 3:
                     state = constants.STATE_PLAYING
                 else:
-                    state = constants.STATE_STANDBY
+                    state = constants.STATE_IDLE
 
             # Get the state from `media_session_state`
             elif media_session_state:
@@ -161,7 +159,7 @@ class AndroidTV(BaseTV):
                 elif media_session_state == 3:
                     state = constants.STATE_PLAYING
                 else:
-                    state = constants.STATE_STANDBY
+                    state = constants.STATE_IDLE
 
             # Get the state from `audio_state`
             elif audio_state != constants.STATE_IDLE:
@@ -174,13 +172,13 @@ class AndroidTV(BaseTV):
                 elif wake_lock_size == 2:
                     state = constants.STATE_PLAYING
                 else:
-                    state = constants.STATE_STANDBY
+                    state = constants.STATE_IDLE
 
         return state, current_app, running_apps, audio_output_device, is_volume_muted, volume_level
 
     # ======================================================================= #
     #                                                                         #
-    #                               properties                                #
+    #                               Properties                                #
     #                                                                         #
     # ======================================================================= #
     def get_properties(self, get_running_apps=True, lazy=False):
@@ -194,7 +192,7 @@ class AndroidTV(BaseTV):
         Parameters
         ----------
         get_running_apps : bool
-            Whether or not to get the :attr:`~androidtv.basetv.BaseTV.running_apps` property
+            Whether or not to get the :meth:`~androidtv.androidtv.AndroidTV.running_apps` property
         lazy : bool
             Whether or not to continue retrieving properties if the device is off or the screensaver is running
 
@@ -302,7 +300,7 @@ class AndroidTV(BaseTV):
         Parameters
         ----------
         get_running_apps : bool
-            Whether or not to get the :attr:`~androidtv.basetv.BaseTV.running_apps` property
+            Whether or not to get the :meth:`~androidtv.androidtv.AndroidTV.running_apps` property
         lazy : bool
             Whether or not to continue retrieving properties if the device is off or the screensaver is running
 
@@ -326,12 +324,6 @@ class AndroidTV(BaseTV):
                 'volume': volume,
                 'running_apps': running_apps}
 
-    # ======================================================================= #
-    #                                                                         #
-    #                               Properties                                #
-    #                                                                         #
-    # ======================================================================= #
-    @property
     def running_apps(self):
         """Return a list of running user applications.
 
