@@ -29,15 +29,13 @@ class FireTV(BaseTV):
         The port for the ADB server
     state_detection_rules : dict, None
         A dictionary of rules for determining the state (see :class:`~androidtv.basetv.BaseTV`)
-    auth_timeout_s : float
-        Authentication timeout (in seconds)
 
     """
 
     DEVICE_CLASS = 'firetv'
 
-    def __init__(self, host, port=5555, adbkey='', adb_server_ip='', adb_server_port=5037, state_detection_rules=None, auth_timeout_s=constants.DEFAULT_AUTH_TIMEOUT_S):
-        BaseTV.__init__(self, host, port, adbkey, adb_server_ip, adb_server_port, state_detection_rules, auth_timeout_s)
+    def __init__(self, host, port=5555, adbkey='', adb_server_ip='', adb_server_port=5037, state_detection_rules=None):
+        BaseTV.__init__(self, host, port, adbkey, adb_server_ip, adb_server_port, state_detection_rules)
 
     # ======================================================================= #
     #                                                                         #
@@ -50,7 +48,7 @@ class FireTV(BaseTV):
         Parameters
         ----------
         get_running_apps : bool
-            Whether or not to get the :attr:`~androidtv.basetv.BaseTV.running_apps` property
+            Whether or not to get the :meth:`~androidtv.firetv.FireTV.running_apps` property
 
         Returns
         -------
@@ -79,7 +77,7 @@ class FireTV(BaseTV):
 
         # Check if screen saver is on
         elif not awake:
-            state = constants.STATE_IDLE
+            state = constants.STATE_STANDBY
             current_app = None
             running_apps = None
 
@@ -95,22 +93,23 @@ class FireTV(BaseTV):
 
             # Determine the state based on the `current_app`
             if current_app in [constants.APP_FIRETV_PACKAGE_LAUNCHER, constants.APP_FIRETV_PACKAGE_SETTINGS, None]:
-                state = constants.STATE_STANDBY
+                state = constants.STATE_IDLE
 
             # Amazon Video
             elif current_app == constants.APP_AMAZON_VIDEO:
-                if wake_lock_size == 5:
+                if media_session_state == 2:
+                    state = constants.STATE_PAUSED
+                elif media_session_state == 3:
                     state = constants.STATE_PLAYING
                 else:
-                    # wake_lock_size == 2
-                    state = constants.STATE_PAUSED
+                    state = constants.STATE_IDLE
 
             # Firefox
             elif current_app == constants.APP_FIREFOX:
                 if wake_lock_size == 3:
                     state = constants.STATE_PLAYING
                 else:
-                    state = constants.STATE_STANDBY
+                    state = constants.STATE_IDLE
 
             # Hulu
             elif current_app == constants.APP_HULU:
@@ -119,7 +118,7 @@ class FireTV(BaseTV):
                 elif wake_lock_size == 2:
                     state = constants.STATE_PAUSED
                 else:
-                    state = constants.STATE_STANDBY
+                    state = constants.STATE_IDLE
 
             # Jellyfin
             elif current_app == constants.APP_JELLYFIN_TV:
@@ -135,7 +134,7 @@ class FireTV(BaseTV):
                 elif media_session_state == 3:
                     state = constants.STATE_PLAYING
                 else:
-                    state = constants.STATE_STANDBY
+                    state = constants.STATE_IDLE
 
             # Plex
             elif current_app == constants.APP_PLEX:
@@ -145,7 +144,7 @@ class FireTV(BaseTV):
                     else:
                         state = constants.STATE_PLAYING
                 else:
-                    state = constants.STATE_STANDBY
+                    state = constants.STATE_IDLE
 
             # Sport 1
             elif current_app == constants.APP_SPORT1:
@@ -154,7 +153,7 @@ class FireTV(BaseTV):
                 elif wake_lock_size == 3:
                     state = constants.STATE_PLAYING
                 else:
-                    state = constants.STATE_STANDBY
+                    state = constants.STATE_IDLE
 
             # Spotify
             elif current_app == constants.APP_SPOTIFY:
@@ -163,7 +162,7 @@ class FireTV(BaseTV):
                 elif media_session_state == 3:
                     state = constants.STATE_PLAYING
                 else:
-                    state = constants.STATE_STANDBY
+                    state = constants.STATE_IDLE
 
             # Twitch
             elif current_app == constants.APP_TWITCH:
@@ -174,7 +173,7 @@ class FireTV(BaseTV):
                 elif media_session_state == 4:
                     state = constants.STATE_PLAYING
                 else:
-                    state = constants.STATE_STANDBY
+                    state = constants.STATE_IDLE
 
             # Waipu TV
             elif current_app == constants.APP_WAIPU_TV:
@@ -183,7 +182,7 @@ class FireTV(BaseTV):
                 elif wake_lock_size == 3:
                     state = constants.STATE_PLAYING
                 else:
-                    state = constants.STATE_STANDBY
+                    state = constants.STATE_IDLE
 
             # Get the state from `media_session_state`
             elif media_session_state:
@@ -192,7 +191,7 @@ class FireTV(BaseTV):
                 elif media_session_state == 3:
                     state = constants.STATE_PLAYING
                 else:
-                    state = constants.STATE_STANDBY
+                    state = constants.STATE_IDLE
 
             # Get the state from `wake_lock_size`
             else:
@@ -205,7 +204,7 @@ class FireTV(BaseTV):
 
     # ======================================================================= #
     #                                                                         #
-    #                               properties                                #
+    #                               Properties                                #
     #                                                                         #
     # ======================================================================= #
     def get_properties(self, get_running_apps=True, lazy=False):
@@ -221,7 +220,7 @@ class FireTV(BaseTV):
         Parameters
         ----------
         get_running_apps : bool
-            Whether or not to get the :attr:`~androidtv.basetv.BaseTV.running_apps` property
+            Whether or not to get the :meth:`~androidtv.firetv.FireTV.running_apps` property
         lazy : bool
             Whether or not to continue retrieving properties if the device is off or the screensaver is running
 
@@ -297,7 +296,7 @@ class FireTV(BaseTV):
         Parameters
         ----------
         get_running_apps : bool
-            Whether or not to get the :attr:`~androidtv.basetv.BaseTV.running_apps` property
+            Whether or not to get the :meth:`~androidtv.firetv.FireTV.running_apps` property
         lazy : bool
             Whether or not to continue retrieving properties if the device is off or the screensaver is running
 
@@ -317,12 +316,6 @@ class FireTV(BaseTV):
                 'media_session_state': media_session_state,
                 'running_apps': running_apps}
 
-    # ======================================================================= #
-    #                                                                         #
-    #                               Properties                                #
-    #                                                                         #
-    # ======================================================================= #
-    @property
     def running_apps(self):
         """Return a list of running user applications.
 
